@@ -5,6 +5,7 @@ Unittests for management commands.
 """
 # from django.core.management import call_command
 from django.test import TestCase
+from django.core.management import call_command
 from calaccess_scraped.management.commands import CalAccessCommand
 
 
@@ -12,20 +13,11 @@ class ScrapedDataCommandsTest(TestCase):
     """
     Run and test management commands.
     """
-    fixtures = [
-        'calaccess_scraped/fixtures/candidate_election.json',
-        'calaccess_scraped/fixtures/candidate.json',
-        'calaccess_scraped/fixtures/incumbent_election.json',
-        'calaccess_scraped/fixtures/incumbent.json',
-        'calaccess_scraped/fixtures/proposition_election.json',
-        'calaccess_scraped/fixtures/proposition.json',
-    ]
-
     def test_commands(self):
         """
         Run the scraping commands.
         """
-        pass
+        call_command("loadcalaccessscrapeddata")
 
     def test_base_command(self):
         """
